This package is designed to simplify the tasks of 19-21 EGE in computer science, which are dedicated to game theory.

Provided four classes (Game1, Game2, Game1Ceil, Game2Ceil) for one and two heaps, and the same, but only with a winning ceiling, respectively. Class Game is abstract and parent to others.